#include "settings.h"
#include "ui_settings.h"

#include <QtCore/QCoreApplication>
#include <QProcess>
#include <QFileInfo>
#include <QSettings>
#include <QString>


Settings::Settings(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::Settings)

{
    ui->setupUi(this);

    ui->checkBoxSecureSetting->setChecked(QSettings().value("SecureSettingSilent", true).toBool());

}
Settings::~Settings()
{
    QSettings().sync();
    delete ui;
}

void Settings::on_checkBoxSecureSetting_clicked()
{
    if (ui->checkBoxSecureSetting->isChecked()) QSettings().setValue("SecureSettingSilent","true");
    else QSettings().setValue("SecureSettingSilent","false");
    QSettings().sync();
}
